@@ -367,7 +367,7 @@ Puppet::Type.type(:augeas).provide(:augeas) do
       load_path.flatten!
     end
 
-    if Puppet::Application.name == :agent
+    if Puppet.run_mode.name == :agent
       if Puppet::FileSystem.exist?("#{Puppet[:libdir]}/augeas/lenses")
         load_path << "#{Puppet[:libdir]}/augeas/lenses"
       end
