@@ -1,7 +1,7 @@
 # The parent class of all AST objects that contain other AST objects.
 # Everything but the really simple objects descend from this.  It is
 # important to note that Branch objects contain other AST objects only --
-# if you want to contain values, use a descendent of the AST::Leaf class.
+# if you want to contain values, use a descendant of the AST::Leaf class.
 #
 # @api private
 class Puppet::Parser::AST::Branch < Puppet::Parser::AST
@@ -12,8 +12,8 @@ class Puppet::Parser::AST::Branch < Puppet::Parser::AST
     @children.each { |child| yield child }
   end
 
-  def initialize(arghash)
-    super(arghash)
-    @children ||= []
+  def initialize(children: [], **args)
+    @children = children
+    super(**args)
   end
 end
