@@ -3,6 +3,11 @@
 class Puppet::Parser::AST::ResourceParam < Puppet::Parser::AST::Branch
   attr_accessor :value, :param, :add
 
+  def initialize(argshash)
+    Puppet.warn_once('deprecations', 'AST::ResourceParam', _('Use of Puppet::Parser::AST::ResourceParam is deprecated and not fully functional'))
+    super(argshash)
+  end
+
   def each
     [@param, @value].each { |child| yield child }
   end
@@ -21,6 +26,6 @@ class Puppet::Parser::AST::ResourceParam < Puppet::Parser::AST::Branch
   end
 
   def to_s
-    "#{@param} => #{@value.to_s}"
+    "#{@param} => #{@value}"
   end
 end
