@@ -1,9 +1,8 @@
 require 'etc'
-require 'facter'
-require 'puppet/parameter/boolean'
-require 'puppet/property/list'
-require 'puppet/property/ordered_list'
-require 'puppet/property/keyvalue'
+require_relative '../../puppet/parameter/boolean'
+require_relative '../../puppet/property/list'
+require_relative '../../puppet/property/ordered_list'
+require_relative '../../puppet/property/keyvalue'
 
 module Puppet
   Type.newtype(:user) do
@@ -466,7 +465,7 @@ module Puppet
       groups = obj.shouldorig if obj
       if groups
         groups = groups.collect { |group|
-          if group =~ /^\d+$/
+          if group.is_a?(String) && group =~/^\d+$/
             Integer(group)
           else
             group
@@ -695,7 +694,7 @@ module Puppet
     end
 
     def generate
-      if !self[:purge_ssh_keys].empty?
+      if !self[:purge_ssh_keys].empty? && self[:purge_ssh_keys] != :false
         return [] if self[:ensure] == :present && !provider.exists? 
         if Puppet::Type.type(:ssh_authorized_key).nil?
           warning _("Ssh_authorized_key type is not available. Cannot purge SSH keys.")
